#
# spec file for package jfsutils
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jfsutils
Version:        1.1.15
Release:        20.6
Summary:        IBM JFS Utility Programs
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            http://jfs.sourceforge.net/
Source0:        http://jfs.sourceforge.net/project/pub/%{name}-%{version}.tar.gz
Source1:        jfs.pdf
Source2:        jfslayout.pdf
Source3:        jfslog.pdf
Source4:        jfsroot.html
Source5:        jfs.txt
Patch1:         jfs-headers.patch
Patch2:         sysmacros.patch
Patch3:         libfs-Fixing-issue-with-variable-name-collision.patch
Patch4:         jfsutils_format-security_ftbs.patch
BuildRequires:  e2fsprogs-devel
Provides:       jfsprogs = %{version}
Obsoletes:      jfsprogs < %{version}
Supplements:    filesystem(jfs)

%description
This package contains utilities for managing IBM's Journaled File
System (JFS) under Linux.  The following utilities are available:

o fsck.jfs--initiate replay of the JFS transaction log and check and
repair a JFS formatted device o logdump--dump a JFS formatted device's
journal log o logredo--replay a JFS formatted device's journal log o
mkfs.jfs--create a JFS formatted partition o xchkdmp--dump the contents
of a JFS fsck log file created with xchklog o xchklog--extract a log
from the JFS fsck workspace into a file o xpeek--shell-type JFS file
system editor

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
sed -i -e 's@^\./"@\." @' fsck/jfs_fsck.8 \
	 fscklog/jfs_fscklog.8 \
	 logdump/jfs_logdump.8 \
	 mkfs/jfs_mkfs.8 \
	 tune/jfs_tune.8 \
	 xpeek/jfs_debugfs.8
tail +35 mkfs/jfs_mkfs.8 | head -10
%configure
make %{?_smp_mflags}

%install
mkdir ./jfsdocs
install -m 644 %{SOURCE1} ./jfsdocs
install -m 644 %{SOURCE2} ./jfsdocs
install -m 644 %{SOURCE3} ./jfsdocs
install -m 644 %{SOURCE4} ./jfsdocs
install -m 644 %{SOURCE5} ./jfsdocs
make DESTDIR=%{buildroot} install %{?_smp_mflags}

%files
%license COPYING
%doc AUTHORS NEWS ChangeLog jfsdocs/*
%{_mandir}/man8/*
%{_sbindir}/*

%changelog
* Tue May 17 2022 Dirk Müller <dmueller@suse.com>
- add jfsutils_format-security_ftbs.patch
* Mon Oct 11 2021 David Disseldorp <ddiss@suse.com>
- UsrMerge: don't override _sbindir (bsc#1191065)
* Wed Apr 29 2020 Martin Liška <mliska@suse.cz>
- Added patch: libfs-Fixing-issue-with-variable-name-collision.patch
- Remove not needed -fcommon.
* Mon Apr 27 2020 Martin Liška <mliska@suse.cz>
- Enable -fcommon in order to fix boo#1160272.
* Wed Aug  1 2018 schwab@suse.de
- sysmacros.patch: include <sys/sysmacros.h> for major
* Wed Mar 18 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use url for source
* Fri Nov 16 2012 aj@suse.de
- Fix missing include (patch jfs-headers.patch).
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Sun Jun 19 2011 per@opensuse.org
- update to version 1.1.15
  * Several fixes for large filesystems where 64-bit variables are needed
  * Fix incorrect size check on directories
  * Make the timestamp format consistent
- spec: add sed-script to fix warnings wrt formatting of man-pages
* Fri Nov 13 2009 jnelson-suse@jamponi.net
- update to version 1.1.14
  * Fix journal replay to handle records that span 3 pages
  * Increase the maximum inline journal size from 32 MB to 128 MB
  * Don't call ioctl(BLKFLSBUF) on a ramdisk.  It wipes out everything.
  * Fix fsck abort
- changes in 1.1.13
  * Rewrite a confusing error messages
  * Improve sanity checking when replaying the journal
  * Work around _LARGEFILE_SOURCE not getting defined by autoconf
  * Remove unhelpful allocation debug messages
* Mon Jun 30 2008 mkoenig@suse.de
- update to version 1.1.12
  * Allow -n flag to be passed to jfs_fsck in conjuction with
  - f, -a, or -p
  * Look for external journal in /proc/mdstat in case of raid
- remove patches
  jfsutils-1.1.8-missingdecl.diff
  jfsutils-1.1.11-open_fix.patch
* Mon Nov 26 2007 mkoenig@suse.de
- fix build: missing third argument for open
* Wed Apr  4 2007 mkoenig@suse.de
- add Supplements line [FATE#301966]
* Mon Jul 10 2006 mskibbe@suse.de
- update to version 1.1.11 which
  o includes patches
    jfsutils-1.1.10-missingreturn.diff
    jfsutils-1.1.10-use_gnu_basename.patch
  o Add compiler flags to generate useful warnings
  o Eliminate compiler warnings
  o Fix segfault in markImap
  o Fix buffer overflow
  o clean up
* Mon May 22 2006 hvogel@suse.de
- define fsck_message.c to be _GNU_SOURCE so we get the declaration
  for basename from string.h. Fixes a segfault on s390x [#177131]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 mmj@suse.de
- dirty_index_page is void not int [#141064]
* Wed Oct 19 2005 mmj@suse.de
- Update to 1.1.10:
  o More stdio cleanup
  o fsck was not recognizing the root filesystem as jfs
* Wed Oct  5 2005 mmj@suse.de
- Update to 1.1.9:
  o Add support for Dragonfly BSD.  Change to use stream I/O.
  o Reduce memory usage in fsck by removing structure members and
    code relating to OS/2 DASD limits.
  o Fix stack buffer overflow in Is_Device_Mounted
* Wed Jul  6 2005 mmj@suse.de
- Fix missing decls
* Wed May  4 2005 mmj@suse.de
- Update to 1.1.8:
  o fsck should not bail out if reserved (but unused) inode 1 is bad
  o code cleanup - remove unused variables, eliminate compiler warnings
  o Added blocks parameter to jfs_mkfs to specify file system size
  o Ensure that data gets flushed to disk
  o Fix bug in replaying journal that corrupted inodes
  o Update directory index table when moving directory entries
  o Use O_DIRECT when checking for bad blocks (jfs_mkfs -c)
* Wed Aug 11 2004 mmj@suse.de
- Update to 1.1.7:
  o --replay_journal_only shouldn't clear FM_DIRTY
  o Ensure changes to disk occur in proper order
  o Message corrections
  o Directory Index Table corrections for big-endian systems
* Thu Apr 29 2004 mmj@suse.de
- Update to 1.1.6 which contains the function for fsck to verify
  and fix the directory inode tables [#39627]
* Fri Apr 16 2004 mmj@suse.de
- Compile with -fno-strict-aliasing
* Mon Mar  8 2004 mmj@suse.de
- Update to 1.1.5:
  o Fix problem creating entries in lost+found
  o Fix buffer overflow
  o Fix replaying of symlink journal records
  o Improve performance of duplicate block checking
  o Fix segfault when printing an errant message
  o Don't open volume with O_EXCL unless it's necessary
  o Support sharing of journal between multiple volumes
* Fri Oct 31 2003 mmj@suse.de
- Update to 1.1.4:
  o Work around gcc 2.95 bug
  o Handle log full without crashing
  o Message format fix
* Thu Oct 16 2003 mmj@suse.de
- Don't build as root.
- Update to 1.1.3 including:
  o jfs_fsck can now find external journal on evms release 2 volumes
  o code cleanup: fsck messaging is much cleaner
  o Don't right-justify when printing volume label
  o jfs_fsck should return zero when replaying the journal is successful
  o jfs_fsck should not require that the device is opened with O_EXCL
  - A recent change to the 2.6.0 kernel makes O_EXCL fail when the
    volume is mounted, even if read-only
* Wed Mar 26 2003 mmj@suse.de
- Update to 1.1.2:
  o fix undefined reference to errno
  o allow jfs_mkfs to run on regular file
  o fix for-loop going past last element of vopen array
  o sanity checking on variable this_ag
  o s_label displayed incorrectly when 16 chars long
* Fri Jan 10 2003 mmj@suse.de
- Update to 1.1.1:
  o fix segmentation fault in mkfs.jfs when given bad block device
  o fix jfs_debugfs to display directory index with directory entries
* Fri Nov 29 2002 mmj@suse.de
- Add missing #include <errno.h>
* Wed Nov 20 2002 mmj@suse.de
- Update to 1.1.0, which renames all tools to be prepended with
  jfs_, except mkfs and fsck
* Sun Oct 20 2002 mmj@suse.de
- Update to 1.0.24
  o byte-swapping fixes for big-endian hardware [#21085] [#19487]
* Fri Sep 27 2002 mmj@suse.de
- update to 1.0.23
  o print fsck.jfs start timestamp correctly in fsck.jfs log
  o allow xchklog to run on a JFS file system with an external journal
  o initialize program name in logdump properly
  o code cleanup
* Thu Sep 19 2002 mmj@suse.de
- update to 1.0.22
  o correctly store a volume label in superblock s_label
  o pass external journal volume label
  o better portability
  o external journal fixes
* Mon Aug 12 2002 bk@suse.de
- update to 1.0.21
  o add external log support to xpeek
  o fix fsck.jfs to update log device number in superblock after
    logredo with external log.
  o do not build currently unused defrag, extendfs utilities
  o add logsuper functions to libfs
  o fix printf format specifiers.  (Christoph Hellwig)
  o update JFS FSIM for EVMS
* Mon Jul  8 2002 bk@suse.de
- update to 1.0.20
  o don't display heartbeat during log format if output is redirected
  o enhance jfsutils to support enormous disks like 8TB+ (Peter C.)
  o set version in JFS superblock properly if external log is used
* Wed Jun  5 2002 ro@suse.de
- added e2fsprogs-devel to neededforbuild
  (needed for uuid.h)
* Wed Jun  5 2002 bk@suse.de
- update to 1.0.18
  o add support for external log
  o endian code cleanup
  o fix typo in fsck.jfs help
  o fix fsck.jfs bug on big endian machines
* Tue Apr  9 2002 bk@suse.de
- update to 1.0.17
  o more rigorous dtree validation in fsck.jfs
  o fix fsck.jfs to write to the fsck.jfs log properly on big endian machines
  o fix xchklog to read the fsck.jfs log properly on big endian machines
  o fix xpeek to display/modify PXD information properly on big endian machines
  o replace fsck.jfs heartbeat with alarm() based heartbeat (Christoph Hellwig)
  o improve mkfs.jfs and fsck.jfs parameter parsing and usage alerts
  o messaging code cleanup, logredo code cleanup, general code cleanup (all)
* Wed Mar 20 2002 bk@suse.de
- update to 1.0.16
  o make fsck.jfs exit codes conform to fsck (see updated fsck.jfs man page)
  o display/log fsck.jfs exit code in debug exit msg
  o fix xchkdmp to print logredo messages
  o make xchkdmp print message text instead of message number
  o use PBSIZE for physical block size instead of BLKSSZGET ioctl
  (eliminates MD error msg "used obsolete MD ioctl", fixes S/390 mkfs.jfs)
  o remove libfs open/close wrappers (Christoph Hellwig)
  o messaging code cleanup, general code cleanup (all)
* Mon Feb 18 2002 grimmer@suse.de
- update to 1.0.15:
  o eliminate invalid fsck.jfs internal error 10
  o update xpeek and fsck.jfs man pages
  o better error message if device to be fsck.jfs'ed is not jfs
  o add support for 4.4 BSD-style getmntinfo
  o include sys/types.h for BSD
  o use defacto standard autoconf macro for large file support
  o general jfsutils code cleanup
* Wed Jan 30 2002 grimmer@suse.de
- renamed package from jfsprogs to jfsutils to be compliant with
  upstream source and added Provides: and Obsoletes: tags
- update to 1.0.14:
  o fix typecast problem causing fsck.jfs 'corrupt superblock'
    error message
  o remove old types PVOID, UCHAR, USHORT, ULONG (code cleanup)
- bzipped sources
* Tue Jan 22 2002 grimmer@suse.de
- update to 1.0.12:
  o autoheader must precede automake
  o use current date as release date in jfs utils
  o fix fsck to update maps at auto check time
  o fix file system utilities to be more portable
* Wed Dec 19 2001 grimmer@suse.de
- update to 1.0.11 which fixes the following bugs:
  o Convert JFS utilities to use autoconf/automake
  o Display correct error messages for disk not accessible
  o Have all utilities print version number
  o Convert JFS utilities to use autoconf/automake
- fixed file list and spec file to build with automake
- man_html has been removed
* Sat Dec  1 2001 grimmer@suse.de
- update to 1.0.10 which fixes the following bug:
  o fsck shouldn't endian swap dtree struct twice
* Fri Nov  9 2001 bk@suse.de
- update to 1.0.9 which fixes the following bugs:
  o don't print heartbeat if fsck.jfs output is redirected
  o make mkfs.jfs options conform to mkfs, clean up parse code
  o fix typo in mkfs.jfs man_html page
  o allow xpeek to show us directory xtrees
  o fix fsck.jfs infinite loop on big endian hardware
    (jitterbug 182)
* Wed Oct 17 2001 mantel@suse.de
- updated to 1.0.8 which fixes the following bugs:
  o cleanup option handling (make -y behave, -f override -p)
  o Add more informative error message when running fsck.jfs RO
  o clean up remove carriage return after new line in messaging
  o print mkfs.jfs version correctly
  o Synclist was being built backwards causing logredo to quit
    too early
* Thu Oct 11 2001 grimmer@suse.de
- Update to 1.0.7 which fixes the following bugs:
  o improve fsck's 'mounted' detection (this will remove the fsck
    message 'Cannot access file system description file to determine
  mount status and file system type of /dev/device name') [#11309]
  o improve utils' checking for fs type jfs
  o replace __uX with uintX_t - (Thanks Fred Oberhauser)
  o change fsck.jfs options to be similar to e2fsck
  o set fsck.jfs default to automatically fix the file system
- removed uintX_t_for__uX.patch since it has been integrated into
  the official sources now
* Tue Oct  2 2001 grimmer@suse.de
- Update to 1.0.6 (bugfixes - see changelog.jfs for details)
- added README and changelog.jfs to the file list
* Tue Sep 18 2001 froh@suse.de
- uintX_t_for__uX.patch: jfsutils/libfs/unicode_to_utf8.{c,h} is
  borrowed from the kernel source tree and uses __uX datatypes from
  <linux/types.h>.  this patch replaces these uses by uintX_t from
  <stdint.h>
* Sun Sep 16 2001 grimmer@suse.de
- Update to 1.0.5 - bugfixes:
  * Fixed jfsprogs.spec to handle utilities not being in file
    system source tree
  * Cleaned up include files
  * Fixed inconsistencies in mkfs man, html pages
* Wed Sep  5 2001 grimmer@suse.de
- Update to 1.0.4
* Thu Aug 23 2001 grimmer@suse.de
- Update to 1.0.3
- now uses the separated jfsutils tarball (utils have been split
  from the kernel sources)
- reworked spec file to fit the new tarball file locations
* Tue Aug  7 2001 grimmer@suse.de
- Update to 1.0.2 (bugfix release, see the changelog for details)
- removed bus_error.patch (now included in upstream sources)
* Thu Aug  2 2001 grimmer@suse.de
- added bus_error.patch (posted by Barry Arndt <barndt@us.ibm.com> on
  jfs-discussion@dwoss.lotus.com) to fix a bus error on SPARC
  when runnning mkfs.jfs (wrong typecast in indodes.c causes a
  value of 1 being added to the address of buffer, resulting in
  an odd numbered address in buf_ai)
* Wed Jul 11 2001 grimmer@suse.de
- update to 1.0.1
- removed now obsolete patch for mkfs.jfs
* Thu Jul  5 2001 grimmer@suse.de
- added patch from <kkaempf@suse.de> to add a "-f" option
  to mkfs.jfs (this disables the "Are you sure?" confirmation)
- updated mkfs.jfs manual page to reflect the change
* Fri Jun 29 2001 grimmer@suse.de
- initial package (version 1.0.0)
- added various documentation from the web site
  (JFS Overview Paper, JFS Layout Paper, JFS Log
  Paper, JFS Root Boot HOWTO)
